@@ -6,6 +6,14 @@ class RestEnumerations:
     '''
     used when creating a unit point on map
     '''
+    teams = {
+        "Cyan": "Cyan",
+        'Red': 'Red',
+        'Yellow': 'Yellow',
+        'Green': 'Green',
+        'Blue': 'Blue'
+    }
+
     SquadTypes = {
         "Gnd Combat Infantry Rifleman": "a-.-G-U-C-I",
         "Gnd Combat Infantry grenadier": "a-.-G-E-W-Z",
@@ -19,6 +27,9 @@ class RestEnumerations:
         "Gnd Combat Infantry Engineer": "a-.-G-U-C-E"
     }
 
+    '''
+    used when creating a shape
+    '''
     otherTypes = {
         "Ground": "a-.-G"
     }
@@ -28,6 +39,9 @@ class RestEnumerations:
     supportedTypeEnumerations.update(otherTypes)
     supportedTypeEnumerations.update(SquadTypes)
 
+    """
+    used when creating an emergency
+    """
     emergencyTypes = {
         "911 Alert": "b-a-o-tbl",
         "Ring The Bell": "b-a-o-pan",
@@ -35,6 +49,9 @@ class RestEnumerations:
         "In Contact": "b-a-o-opn",
     }
 
+    """
+    used to define how the message is sent
+    """
     how = {
         "mensurated": "m-i",
         "human": "h-t",
